#!/bin/bash
#
# upgrade_firmware.sh
# version 0.3
# The script uploads a new firmware file and upgrade script (cli_upgrade_ray.sh) into the local RAy unit
# The script on the local RAy unit is executed and runs the upgrade procedure
# Both RAy units are upgraded (only the different firmware parts)
#
# Example:
# sh upgrade_firmware.sh "192.168.169.169" "/home/.ssh/keys/admin_ray_key" "8022" "/home/firmware/ray/bm4-1.1.5.cpio" "1.1.5.0"

# Displaying the help text:
if [ $# -eq 0 ] || [ "$1" = "--help" ] || [ "$1" = "-h" ]; then
	echo 'See the code for the description. Example: sh upgrade_firmware.sh "192.168.169.169" "/home/.ssh/keys/admin_ray_key" "8022" "/home/firmware/ray/bm4-1.1.5.cpio" "1.1.5.0"'
	exit 0
fi

# Check the number of input parameters (= 5)
if [ $# -ne 5 ]; then
	echo 'Wrong number of parameters (see the code for the description). Example: sh upgrade_firmware.sh "192.168.169.169" "8022" "/home/.ssh/keys/admin_ray_key" "both" "/home/firmware/ray/bm4-1.1.5.cpio" "1.1.5.0"'
	exit 99
fi

# Parameters (must be in this order!):

# Local RAy IP address
# e.g. "192.168.169.169"
DEVICE_IP=$1

# The file with the local RAy admin SSH key (= no need to enter a password every time)
# e.g. "/home/.ssh/keys/admin_ray_key"
KEY=$2

# Local RAy SSH port
# e.g. "8022"
PORT=$3

# Upgrade only local or both units
# e.g. "local" OR "both"
BOTH_OR_LOCAL="b"

# The firmware file
# e.g. "/home/firmware/ray/bm4-1.1.5.cpio"
FIRMWARE_FILE=$4

# The firmware version which should be on RAy units after the upgrade
# e.g. "1.1.5.0"
FIRMWARE_VERSION=$5

# The upgrade file which will be uploaded to the local RAy unit
SCRIPT_FILE="/usr/lib/zabbix/externalscripts/cli_upgrade_ray.sh"

# Full paths to the SCP and SSH tools
SCP_PATH="/usr/bin/scp"
SSH_PATH="/usr/bin/ssh"

# Check the firmware version on the local RAy unit
# If the current version is the same as the one which should be uploaded, do nothing
# Else copy the needed files into the local RAy unit and run the upgrade procedure
CURRENT_FW=`$SSH_PATH admin@$DEVICE_IP -p "$PORT" -i "$KEY" "source /etc/profile && /usr/bin/cli_info_station" | grep Firmware | cut -d ' ' -f 3`
if [ "$CURRENT_FW" = "$FIRMWARE_VERSION" ]; then
	echo "NO NEED TO UPGRADE THE UNIT"
else 

	# copy the upgrade script and the firmware file to the ray unit
	$SCP_PATH -i "$KEY" -P "$PORT" "$FIRMWARE_FILE" admin@$DEVICE_IP:/tmp/firmware.cpio
	FIRMWARE_COPY=$?

	$SCP_PATH -i "$KEY" -P "$PORT" "$SCRIPT_FILE" admin@$DEVICE_IP:/tmp/cli_upgrade_ray.sh
	SCRIPT_COPY=$?

	# check whether both copy procedures were successful
	if [ "$FIRMWARE_COPY" -eq 0 ] && [ "$SCRIPT_COPY" -eq 0 ]; then 
		# execute the upgrade script
		$SSH_PATH admin@$DEVICE_IP -i "$KEY" -p "$PORT" "source /etc/profile && sh /tmp/cli_upgrade_ray.sh $BOTH_OR_LOCAL &"
		if [ $? -eq 0 ]; then
			echo "SUCCESS: The files were uploaded to the station and the script was executed."
		else 
			echo "FAILURE: The script was NOT executed correctly."
		fi
	else 
		if [ "$FIRMWARE_COPY" -eq 0 ]; then
			echo "FAILURE: The firmware was NOT uploaded to the station."
		fi
		if [ "$SCRIPT_COPY" -eq 0 ]; then
			echo "FAILURE: The CLI upgrade script was NOT uploaded to the station."
		fi
	fi
fi

